==> typedoc-0.4.0.tgz: package/lib/output/theme.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var components_1 = require("./components");
var component_1 = require("../utils/component");
var resources_1 = require("./utils/resources");
var Theme = (function (_super) {
    __extends(Theme, _super);
    function Theme(renderer, basePath) {
        _super.call(this, renderer);
        this.basePath = basePath;
        this.resources = new resources_1.Resources(this);
    }
    Theme.prototype.isOutputDirectory = function (path) {
        return false;
    };
    Theme.prototype.getUrls = function (project) {
        return [];
    };
    Theme.prototype.getNavigation = function (project) {
        return null;
    };
    Theme = __decorate([
        component_1.Component({ name: "rendrer:theme", internal: true })
    ], Theme);
    return Theme;
}(components_1.RendererComponent));
exports.Theme = Theme;

==> typedoc-0.4.4.tgz: package/lib/output/theme.js <==
"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var components_1 = require("./components");
var component_1 = require("../utils/component");
var resources_1 = require("./utils/resources");
var Theme = (function (_super) {
    __extends(Theme, _super);
    function Theme(renderer, basePath) {
        _super.call(this, renderer);
        this.basePath = basePath;
        this.resources = new resources_1.Resources(this);
    }
    Theme.prototype.isOutputDirectory = function (path) {
        return false;
    };
    Theme.prototype.getUrls = function (project) {
        return [];
    };
    Theme.prototype.getNavigation = function (project) {
        return null;
    };
    Theme = __decorate([
        component_1.Component({ name: "theme", internal: true })
    ], Theme);
    return Theme;
}(components_1.RendererComponent));
exports.Theme = Theme;
